/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { AdminOrganisationsEinheitResource } from '@admin-client/admin-settings';
import { AbstractFormService, EMPTY_STRING, StateResource } from '@alfa-client/tech-shared';
import { Injectable } from '@angular/core';
import { FormControl, UntypedFormBuilder, UntypedFormGroup } from '@angular/forms';
import { Observable } from 'rxjs';
import { OrganisationsEinheitService } from '../../organisationseinheit.service';

@Injectable()
export class OrganisationsEinheitFormService extends AbstractFormService {
  public static readonly ORGANISATIONSEINHEIT_SIGNATUR_FIELD: string = 'signatur';

  constructor(
    formBuilder: UntypedFormBuilder,
    private organisationsEinheitService: OrganisationsEinheitService,
  ) {
    super(formBuilder);
  }

  protected initForm(): UntypedFormGroup {
    return this.formBuilder.group({
      [OrganisationsEinheitFormService.ORGANISATIONSEINHEIT_SIGNATUR_FIELD]: new FormControl(EMPTY_STRING),
    });
  }

  protected doSubmit(): Observable<StateResource<AdminOrganisationsEinheitResource>> {
    return this.organisationsEinheitService.patch(this.getFormValue());
  }

  protected getPathPrefix(): string {
    return 'settingBody';
  }
}
