/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import {
  StateResource,
  createEmptyStateResource,
  createErrorStateResource,
  createStateResource,
} from '@alfa-client/tech-shared';
import { Action, ActionReducer, createReducer, on } from '@ngrx/store';
import { CommandResource, CreateCommandProps } from '../command.model';

import { HttpErrorResponse } from '@angular/common/http';
import * as Actions from './command.actions';

export const COMMAND_FEATURE_KEY = 'CommandState';

export interface CommandPartialState {
  readonly [COMMAND_FEATURE_KEY]: CommandState;
}

export interface CommandState {
  commandByOrderMap: { [order: string]: StateResource<CommandResource> };
}

export const initialState: CommandState = {
  commandByOrderMap: {},
};

const commandReducer: ActionReducer<CommandState, Action> = createReducer(
  initialState,
  on(
    Actions.createCommand,
    (state: CommandState, props: CreateCommandProps): CommandState => ({
      ...state,
      commandByOrderMap: {
        ...state.commandByOrderMap,
        [props.command.order]: createEmptyStateResource(true),
      },
    }),
  ),
  on(
    Actions.createCommandSuccess,
    (state: CommandState, props: Actions.CommandProps): CommandState => ({
      ...state,
      commandByOrderMap: {
        ...state.commandByOrderMap,
        [props.command.order]: createStateResource(props.command),
      },
    }),
  ),
  on(
    Actions.createCommandFailure,
    (state: CommandState, props: Actions.CreateCommandFailureProps): CommandState => ({
      ...state,
      commandByOrderMap: {
        ...state.commandByOrderMap,
        [props.command.order]: createErrorStateResource((<HttpErrorResponse>props.error).error),
      },
    }),
  ),
);

export function reducer(state: CommandState, action: Action): CommandState {
  return commandReducer(state, action);
}
