/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { Mock, mock, useFromMock } from '@alfa-client/test-utils';
import { Store } from '@ngrx/store';
import { Subject } from 'rxjs';
import { HintFacade } from './hint.facade';

import * as HintSelectors from './hint.selectors';

describe('HintFacade', () => {
  let facade: HintFacade;
  let store: Mock<Store>;

  let selectionSubject: Subject<any>;

  beforeEach(() => {
    store = mock(Store);

    store.select.mockReturnValue(selectionSubject);
    store.dispatch = jest.fn();

    facade = new HintFacade(useFromMock(<any>store));
  });

  it('is initialized', () => {
    expect(facade).toBeTruthy();
  });

  describe('hasUserNoOrganisationsEinheitIdHint', () => {
    it('should select from store', () => {
      facade.hasUserNoOrganisationsEinheitIdHint();

      expect(store.select).toHaveBeenCalledWith(HintSelectors.hasUserNoOrganisationsEinheitIdHint);
    });
  });
});
