/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { CommandResource } from '@alfa-client/command-shared';
import { PostfachService, PostfachSettings } from '@alfa-client/postfach-shared';
import { StateResource, createStateResource } from '@alfa-client/tech-shared';
import { Mock, mock, useFromMock } from '@alfa-client/test-utils';
import { UntypedFormBuilder } from '@angular/forms';
import { createCommandResource } from 'libs/command-shared/test/command';
import {
  createEmptyPostfachSettings,
  createPostfachMailResource,
  createPostfachSettings,
} from 'libs/postfach-shared/test/postfach';
import { of } from 'rxjs';
import { PostfachMailFormservice } from './postfach-mail.formservice';

describe('PostfachMailFormservice', () => {
  let formService: PostfachMailFormservice;
  let service: Mock<any> = mock(PostfachService);

  const formBuilder: UntypedFormBuilder = new UntypedFormBuilder();
  const postfachSettings: PostfachSettings = createPostfachSettings();

  beforeEach(() => {
    service.getSettings.mockReturnValue(of(postfachSettings));
    formService = new PostfachMailFormservice(formBuilder, useFromMock(service));
  });

  it('should create', () => {
    expect(formService).toBeTruthy();
  });

  describe('submit', () => {
    const commandStateResource: StateResource<CommandResource> =
      createStateResource(createCommandResource());

    beforeEach(() => {
      service.doSubmit = jest.fn();
    });

    describe('on patch', () => {
      beforeEach(() => {
        service.sendExistingMail.mockReturnValue(of(commandStateResource));
      });

      it('should call service', () => {
        formService.source = createPostfachMailResource();

        formService.submit();

        expect(service.sendExistingMail).toHaveBeenCalledWith(
          formService.source,
          formService.form.value,
        );
      });
    });

    describe('on new', () => {
      beforeEach(() => {
        service.sendMail.mockReturnValue(of(commandStateResource));
      });

      it('should call service', () => {
        formService.submit();

        expect(service.sendMail).toHaveBeenCalledWith(formService.form.value);
      });
    });
  });

  describe('initMailBody', () => {
    it('should call service', () => {
      formService.initMailBody();

      expect(service.getSettings).toHaveBeenCalled();
    });

    it('should set field mail body with signatur and newline if signatur is not empty', () => {
      formService.initMailBody();

      const mailBodyValue = formService.form.get(PostfachMailFormservice.FIELD_MAIL_BODY).value;
      expect(mailBodyValue).toBe(`\n${postfachSettings.signatur}`);
    });

    it('should not set field mail body if signatur is empty', () => {
      service.getSettings.mockReturnValue(of(createEmptyPostfachSettings()));
      formService = new PostfachMailFormservice(formBuilder, useFromMock(service));

      formService.initMailBody();

      const mailBodyValue = formService.form.get(PostfachMailFormservice.FIELD_MAIL_BODY).value;
      expect(mailBodyValue).toBe(null);
    });
  });
});
