/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { BescheidService } from '@alfa-client/bescheid-shared';
import { CommandResource, tapOnCommandSuccessfullyDone } from '@alfa-client/command-shared';
import { StateResource, isLoaded } from '@alfa-client/tech-shared';
import { OzgcloudDialogService } from '@alfa-client/ui';
import { VorgangService } from '@alfa-client/vorgang-shared';
import { DialogRef } from '@angular/cdk/dialog';
import { Component } from '@angular/core';
import { Observable, filter, first, switchMap } from 'rxjs';

@Component({
  selector: 'alfa-vorgang-detail-bescheiden-ueberspringen-dialog',
  templateUrl: './vorgang-detail-bescheiden-ueberspringen-dialog.component.html',
})
export class VorgangDetailBescheidenUeberspringenDialogComponent {
  bescheiderstellungUeberspringen$: Observable<StateResource<CommandResource>>;

  constructor(
    private readonly dialogRef: DialogRef,
    private readonly bescheidService: BescheidService,
    private readonly ozgcloudDialogService: OzgcloudDialogService,
    private readonly vorgangService: VorgangService,
  ) {}

  public onClose(): void {
    this.dialogRef.close();
  }

  public onConfirm(): void {
    this.bescheiderstellungUeberspringen$ = this.vorgangService.getVorgangWithEingang().pipe(
      filter(isLoaded),
      first(),
      switchMap((stateResource) =>
        this.bescheidService.bescheidErstellungUeberspringen(stateResource.resource).pipe(
          tapOnCommandSuccessfullyDone(() => {
            this.ozgcloudDialogService.closeAll();
          }),
        ),
      ),
    );
  }

  public onCancel(): void {
    this.dialogRef.close();
  }
}
