/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.alfa.kommentar;

import java.util.Comparator;
import java.util.stream.Stream;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.hateoas.CollectionModel;
import org.springframework.hateoas.EntityModel;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import de.ozgcloud.alfa.common.binaryfile.BinaryFileController;
import de.ozgcloud.alfa.common.file.OzgFile;

@RestController
@RequestMapping(KommentarController.KOMMENTAR_PATH)
public class KommentarController {

	static final String KOMMENTAR_PATH = "/api/kommentars"; // NOSONAR

	@Autowired
	private KommentarService service;

	@Autowired
	private KommentarModelAssembler modelAssembler;

	@Autowired
	private BinaryFileController binaryFileController;

	@GetMapping("/{kommentarId}")
	public EntityModel<Kommentar> getById(@PathVariable String kommentarId) {
		return modelAssembler.toModel(service.getById(kommentarId));
	}

	@GetMapping("/{kommentarId}/attachments")
	public CollectionModel<EntityModel<OzgFile>> getAttachments(@PathVariable String kommentarId) {
		var kommentar = service.getById(kommentarId);
		return binaryFileController.getFiles(kommentar.getAttachments());
	}

	@RestController
	@RequestMapping(KommentarByVorgangController.KOMMENTAR_BY_VORGANG_PATH)
	public static class KommentarByVorgangController {

		static final String KOMMENTAR_BY_VORGANG_PATH = "/api/vorgangs"; // NOSONAR

		@Autowired
		private KommentarService service;

		@Autowired
		private KommentarModelAssembler modelAssembler;

		@GetMapping("/{vorgangId}/kommentars")
		public CollectionModel<EntityModel<Kommentar>> getAll(@PathVariable String vorgangId) {
			return modelAssembler.toCollectionModel(sortByCreatedAt(service.findByVorgangId(vorgangId)), vorgangId);
		}

		Stream<Kommentar> sortByCreatedAt(Stream<Kommentar> kommentare) {
			return kommentare.sorted(Comparator.comparing(Kommentar::getCreatedAt).reversed());
		}
	}
}