/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.alfa.loeschanforderung;

import static org.springframework.hateoas.server.mvc.WebMvcLinkBuilder.*;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.hateoas.EntityModel;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import de.ozgcloud.alfa.common.command.CommandController;
import de.ozgcloud.alfa.common.command.CreateCommand;
import de.ozgcloud.alfa.vorgang.VorgangController;

@RestController
@RequestMapping(LoeschAnforderungController.BASE_PATH)
public class LoeschAnforderungController {

	static final String BASE_PATH = "/api/loeschanforderungs"; // NOSONAR

	@Autowired
	private LoeschAnforderungService service;

	@Autowired
	private LoeschAnforderungModelAssembler modelAssembler;

	@GetMapping("/{id}")
	public EntityModel<LoeschAnforderung> getLoeschanforderung(@PathVariable String id) {
		return modelAssembler.toModel(service.getById(id));
	}

	@RestController
	@RequestMapping(LoeschAnforderungByVorgangController.BASE_PATH)
	public static class LoeschAnforderungByVorgangController {

		public static final String BASE_PATH = "/api/vorgangs/{vorgangId}/vorgangVersion/{vorgangVersion}/loeschanforderung"; // NOSONAR

		@Autowired
		private LoeschAnforderungService loeschAnforderungService;

		@Autowired
		private VorgangController vorgangController;

		@PostMapping
		public ResponseEntity<Void> createLoeschAnforderung(@PathVariable String vorgangId, @PathVariable long vorgangVersion,
				@RequestBody CreateCommand command) {
			var vorgang = vorgangController.getVorgang(vorgangId);
			var created = loeschAnforderungService.createLoeschAnforderung(command, vorgang, vorgangVersion);

			return ResponseEntity.created(linkTo(CommandController.class).slash(created.getId()).toUri()).build();
		}
	}
}
