/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.alfa.vorgang;

import java.util.Collection;
import java.util.Optional;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import de.ozgcloud.alfa.common.user.CurrentUserService;
import de.ozgcloud.alfa.common.user.UserRole;
import de.ozgcloud.alfa.vorgang.Vorgang.VorgangStatus;

@Service
class VorgangService {

	@Autowired
	private VorgangRemoteService remoteService;
	@Autowired
	private CurrentUserService userService;

	public VorgaengeHeaderResponse findVorgaengeHeader(FindVorgaengeHeaderRequestCriteria requestCriteria) {
		requestCriteria = setOrderBy(requestCriteria);

		return remoteService.findVorgaengeHeader(requestCriteria, buildFilterCriteria(requestCriteria.getFilterCriteria()));
	}

	FindVorgaengeHeaderRequestCriteria setOrderBy(FindVorgaengeHeaderRequestCriteria requestCriteria) {
		if (userService.hasRole(UserRole.EINHEITLICHER_ANSPRECHPARTNER)) {
			return requestCriteria.toBuilder().orderBy(OrderBy.EA_PRIORITY).build();
		}
		if (userService.hasRole(UserRole.VERWALTUNG_POSTSTELLE)) {
			return requestCriteria.toBuilder().orderBy(OrderBy.PRIORITY).build();
		}
		return setOrderByForVerwaltungUser(requestCriteria);
	}

	private FindVorgaengeHeaderRequestCriteria setOrderByForVerwaltungUser(FindVorgaengeHeaderRequestCriteria requestCriteria) {
		if (requestCriteria.getFilterCriteria().getStatus().isPresent()) {
			return requestCriteria.toBuilder().orderBy(OrderBy.CREATED_AT_DESC).build();
		}
		if (requestCriteria.getFilterCriteria().isHasNextWiedervorlageFrist()) {
			return requestCriteria.toBuilder().orderBy(OrderBy.NEXT_WIEDERVORLAGE_FRIST).build();
		}
		return requestCriteria.toBuilder().orderBy(OrderBy.PRIORITY).build();
	}

	public VorgangWithEingang findVorgangWithEingang(String vorgangId) {
		return remoteService.findVorgangWithEingang(vorgangId, buildFilterCriteria(FilterCriteria.builder().build()));
	}

	FilterCriteria buildFilterCriteria(FilterCriteria filterCriteria) {
		if (userService.hasRole(UserRole.VERWALTUNG_POSTSTELLE)) {
			return buildFilterByForPoststelle(filterCriteria);
		}
		if (userService.hasRole(UserRole.EINHEITLICHER_ANSPRECHPARTNER)) {
			return buildFilterByForEa(filterCriteria);
		}
		return buildFilterByForOtherRoles(filterCriteria);
	}

	private FilterCriteria buildFilterByForPoststelle(FilterCriteria filterCriteria) {
		return filterCriteria.toBuilder().filterByOrganisationseinheitenId(false).status(Optional.of(VorgangStatus.NEU)).build();
	}

	private FilterCriteria buildFilterByForEa(FilterCriteria filterCriteria) {
		return filterCriteria.toBuilder().filterByOrganisationseinheitenId(false).build();
	}

	private FilterCriteria buildFilterByForOtherRoles(FilterCriteria filterCriteria) {
		return filterCriteria.toBuilder().filterByOrganisationseinheitenId(true).organisationsEinheitenId(getOrganisationseinheitenIdsFromUser())
				.build();
	}

	private Collection<String> getOrganisationseinheitenIdsFromUser() {
		return userService.getUser().getOrganisationseinheitIds();
	}
}