/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.alfa.bescheid;

import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.UUID;

import com.thedeanda.lorem.LoremIpsum;

import de.ozgcloud.alfa.common.binaryfile.FileId;
import de.ozgcloud.alfa.vorgang.VorgangHeaderTestFactory;

public class BescheidTestFactory {

	public static final String ID = UUID.randomUUID().toString();
	public static final BescheidStatus STATUS = BescheidStatus.DRAFT;
	public static final long VERSION = 42;
	public static final String VORGANG_ID = VorgangHeaderTestFactory.ID;
	public static final String BESCHIEDEN_AM = "2024-05-27";
	public static final boolean BEWILLIGT = true;
	public static final String BESCHEID_DOCUMENT = UUID.randomUUID().toString();
	public static final List<FileId> ATTACHMENTS = List.of(FileId.from(UUID.randomUUID().toString()), FileId.from(UUID.randomUUID().toString()));
	public static final String NACHRICHT_TEXT = LoremIpsum.getInstance().getWords(10);
	public static final String NACHRICHT_SUBJECT = LoremIpsum.getInstance().getWords(3);
	public static final SendBy SEND_BY = SendBy.MANUAL;
	public static final SentInfo SENT_INFO = SentInfoTestFactory.create();

	public static Bescheid.BescheidBuilder createBuilder() {
		return Bescheid.builder()
				.id(ID)
				.status(STATUS)
				.version(VERSION)
				.vorgangId(VORGANG_ID)
				.beschiedenAm(BESCHIEDEN_AM)
				.bewilligt(BEWILLIGT)
				.bescheidDocument(BESCHEID_DOCUMENT)
				.attachments(ATTACHMENTS)
				.nachrichtText(NACHRICHT_TEXT)
				.nachrichtSubject(NACHRICHT_SUBJECT)
				.sendBy(SEND_BY)
				.sentInfo(SENT_INFO);
	}

	public static Bescheid create() {
		return createBuilder().build();
	}

	public static Map<String, Object> createAsMap() {
		var map = new HashMap<String, Object>();
		map.put(Bescheid.ID_FIELD, ID);
		map.put(Bescheid.STATUS_FIELD, STATUS);
		map.put(Bescheid.VERSION_FIELD, VERSION);
		map.put(Bescheid.VORGANG_ID_FIELD, VORGANG_ID);
		map.put(Bescheid.BESCHIEDEN_AM_FIELD, BESCHIEDEN_AM);
		map.put(Bescheid.BEWILLIGT_FIELD, BEWILLIGT);
		map.put(Bescheid.BESCHEID_DOCUMENT_FIELD, BESCHEID_DOCUMENT);
		map.put(Bescheid.ATTACHMENTS_FIELD, ATTACHMENTS);
		map.put(Bescheid.NACHRICHT_TEXT_FIELD, NACHRICHT_TEXT);
		map.put(Bescheid.NARCHRICHT_SUBJECT_FIELD, NACHRICHT_SUBJECT);
		map.put(Bescheid.SEND_BY_FIELD, SEND_BY);
		return map;
	}
}