/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.alfa.postfach;

import static de.ozgcloud.alfa.postfach.PostfachMailTestFactory.*;

import java.util.Arrays;

import de.ozgcloud.alfa.common.binaryfile.BinaryFileTestFactory;
import de.ozgcloud.nachrichten.postfach.GrpcDirection;
import de.ozgcloud.nachrichten.postfach.GrpcFindPostfachMailResponse;
import de.ozgcloud.nachrichten.postfach.GrpcFindPostfachMailsResponse;
import de.ozgcloud.nachrichten.postfach.GrpcPostfachMail;

public class GrpcPostfachMailTestFactory {

	public static GrpcPostfachMail create() {
		return createBuilder().build();
	}

	public static GrpcPostfachMail.Builder createBuilder() {
		return GrpcPostfachMail.newBuilder()
				.setId(ID)
				.setVorgangId(VORGANG_ID)
				.setPostfachId(PostfachAddressTestFactory.STRING_BASED_IDENTIFIER_POSTFACH_ID)
				.setCreatedAt(CREATED_AT_STR)
				.setCreatedBy(CREATED_BY.toString())
				.setSentAt(SENT_AT_STR)
				.setSentSuccessful(SENT_SUCCESSFUL)
				.setMessageCode(MESSAGE_CODE)
				.setDirection(GrpcDirection.OUT)
				.setReplyOption(REPLY_OPTION.name())
				.setSubject(SUBJECT)
				.setMailBody(MAIL_BODY)
				.addAttachment(BinaryFileTestFactory.ID);
	}

	public static GrpcFindPostfachMailsResponse createFindPostfachMailsResponse() {
		return GrpcFindPostfachMailsResponse.newBuilder()
				.addAllMails(Arrays.asList(create()))
				.build();
	}

	public static GrpcFindPostfachMailResponse createFindPostfachMailResponse() {
		return GrpcFindPostfachMailResponse.newBuilder()
				.setNachricht(create())
				.build();
	}
}